<?php

namespace Drupal\communities\Form;

use Drupal\Core\Entity\ContentEntityDeleteForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for deleting Community entities.
 *
 * @ingroup communities
 */
class CommunityDeleteForm extends ContentEntityDeleteForm {

  /**
   * @{inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $default_community = \Drupal::service('community_manager')->getDefaultCommunity();
    if (!$this->defaultCommunityExists($default_community)) {
      $this->updateDefaultCommunity();
    }
  }

  /**
   * @{inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // TODO: Change the autogenerated stub.
    parent::validateForm($form, $form_state);
    $default_community = \Drupal::service('community_manager')->getDefaultCommunity();
    if ($this->getEntity()->id() == $default_community) {
      $form_state->setErrorByName('submit', $this->t('You cannot delete the default community. Please update the default community in settings and try again.'));
    }
  }

  /**
   * Checks to see if the default community exists.
   */
  public function defaultCommunityExists($default_community_id) {
    $community = \Drupal::service('community_manager')->getCommunity($default_community_id);
    if ($community == NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Updates the default community.
   */
  public function updateDefaultCommunity() {
    $new_default = reset(\Drupal::entityTypeManager()->getStorage('community')->loadMultiple());
    /** @var \Drupal\communities\CommunityManagerInterface $community_manager */
    $community_manager = \Drupal::service('community_manager');
    if ($new_default != FALSE) {
      $community_manager->setDefaultCommunity($new_default->id());
    }
    else {
      $community_manager->setDefaultCommunity(-1);
    }
  }

}
